@@ -814,3 +814,46 @@ CHAR_space = [
     b"\x00\x00\x00\x00\x00",
     b"\x00\x00\x00\x00\x00",
 ]
+
+CHAR_NOT_FOUND = [
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFE\x00\x7F\xFF",
+    b"\xFF\xFE\x00\x7F\xFF",
+    b"\xFF\xFE\x00\x7F\xFF",
+    b"\xFF\xFE\x00\x7F\xFF",
+    b"\xFF\xFE\x00\x7F\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xC0\x00\x7F\xFF",
+    b"\xFF\xC0\x00\x7F\xFF",
+    b"\xFF\xC0\x00\x7F\xFF",
+    b"\xFF\xC0\x00\x7F\xFF",
+    b"\xFF\xC0\x00\x7F\xFF",
+    b"\xF8\x01\xFF\xFF\xFF",
+    b"\xF8\x01\xFF\xFF\xFF",
+    b"\xF8\x01\xFF\xFF\xFF",
+    b"\xF8\x01\xFF\xFF\xFF",
+    b"\xF8\x01\xFF\xFF\xFF",
+    b"\xF8\x01\xFF\x80\x1F",
+    b"\xF8\x01\xFF\x80\x1F",
+    b"\xF8\x01\xFF\x80\x1F",
+    b"\xF8\x01\xFF\x80\x1F",
+    b"\xF8\x01\xFF\x80\x1F",
+    b"\xFF\xC0\x00\x03\xFF",
+    b"\xFF\xC0\x00\x03\xFF",
+    b"\xFF\xC0\x00\x03\xFF",
+    b"\xFF\xC0\x00\x03\xFF",
+    b"\xFF\xC0\x00\x03\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+    b"\xFF\xFF\xFF\xFF\xFF",
+]
